@@ -4,26 +4,42 @@ from __future__ import print_function
 from contextlib import contextmanager
 from antgo.dataflow.dataset import *
 import antvis.client.mlogger as mlogger
+import os
 
 
 class Params(object):
   def __init__(self, params={}):
-    if params is not None:
-      for k, v in params.items():
-        if k != 'self':
-          setattr(self, k, v)
-
+    assert(type(params) == dict)
+    # if params is not None:
+    #   for k, v in params.items():
+    #     if k != 'self':
+    #       setattr(self, k, v)
+    # self.__dict__.update(params)
     self._params = params
 
   def define(self, k, v=None):
-    setattr(self, k, v)
+    # setattr(self, k, v)
     self._params[k] = v
 
-  def __getattr__(self, item):
-    if item not in object.__dict__:
-      return None
+  def get(self, item=None, default=None):
+    if item is None:
+      return self._params
 
-    return object.__dict__[item]
+    if item not in self._params:
+      return default
+
+    return self._params[item]
+
+  def __getattr__(self, item):
+    if item not in self._params:
+      return None
+    if type(self._params[item]) == dict:
+      return Params(self._params[item])
+
+    return self._params[item]
+
+  def keys(self):
+    return self._params.keys()
 
   def items(self):
     return self._params.items()
@@ -59,16 +75,29 @@ class _Block(object):
   
   def __exit__(self, exc_type, exc_val, exc_tb):
     pass
-  
+
+
+class _DataProcessor(object):
+  def __init__(self):
+    self.processor_sequence = []
+
+  def add(self, *args):
+    self.processor_sequence.extend(args)
+
+  def iterator(self, source):
+    upper = source
+    for processor_cls in self.processor_sequence:
+      upper = processor_cls(Node.inputs(upper))
+
+    return upper.iterator_value()
+
 
 class Context(object):
-  def __init__(self):
+  def __init__(self, interact_mode=False):
     global global_context
-    # assert(global_context == None)
-
     self.training_process_callback = None
     self.infer_process_callback = None
-    self._data_processor = None
+    self._data_processor = _DataProcessor()
     self.running_recorder = None
     self.context_params = None
     
@@ -99,6 +128,13 @@ class Context(object):
     self._data_factory = None
     self._main_folder = None
     self._experiment_uuid = None
+    self._is_interact_mode = interact_mode
+
+    # 注册用户数据
+    self.register_obj = {}
+
+  def is_interact_mode(self):
+    return self._is_interact_mode
 
   def wait_until_clear(self):
     for stoppable_thread in self._stoppable_threads:
@@ -168,6 +204,12 @@ class Context(object):
   def model(self, val):
     self._model = val
 
+  def register(self, **kwargs):
+    self.register_obj.update(kwargs)
+
+  def register_at(self, key):
+    return self.register_obj.get(key, None)
+
   @property
   def training_process(self):
     return self.training_process_callback
@@ -222,10 +264,6 @@ class Context(object):
   def data_processor(self):
     return self._data_processor
 
-  @data_processor.setter
-  def data_processor(self, g):
-    self._data_processor = g
-
   @property
   def recorder(self):
     return self.running_recorder
