@@ -10,14 +10,21 @@ from .operators import (
   Rotation,
   KeepRatio, 
   ColorDistort,
-  AutoAugmentImage,
   RandomErasingImage,
   CropImage,
-  ExpandImage,
-  Permute,
   MixupImage,
   CutmixImage,
-  Meta)
+  Meta,
+  RandomScaledCrop,
+  ResizeByLong,
+  ResizeRangeScaling,
+  ResizeStepScaling,
+  AutoAugmentImage,
+  Permute,
+  UnSqueeze,
+  ConvertRandomObjJointsAndOffset,
+  ResizeByShort,
+  FixedCrop)
 
 __all__ = [
   'DecodeImage', 
@@ -27,12 +34,19 @@ __all__ = [
   'Rotation', 
   'KeepRatio', 
   'ColorDistort',
-  'AutoAugmentImage',
   'RandomErasingImage',
   'CropImage',
-  'ExpandImage',
   'Permute',
   'MixupImage',
   'CutmixImage',
+  'RandomScaledCrop',
+  'ResizeByLong',
+  'ResizeRangeScaling',
+  'ResizeStepScaling',
+  'AutoAugmentImage',
+  'UnSqueeze',
+  'ConvertRandomObjJointsAndOffset',
+  'ResizeByShort',
+  'FixedCrop',
   'Meta'
 ]
