@@ -4,3 +4,5 @@ from .detectors import *
 from .nas import *
 from .activelearning import *
 from .adda import *
+from .pose3d import *
+from .segmentation import *
